Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(42)

Unified Diff: third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp

Issue 1421113006: Detach the globals of all frames, not just the main frame (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: git cl try Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp
diff --git a/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp b/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp
index 4a354bc7fb70624629aa131c0352746359a4041c..068b0223885c8b172dfd6b92ccef6a37c11acfc0 100644
--- a/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp
+++ b/third_party/WebKit/Source/bindings/core/v8/ScriptController.cpp
@@ -131,13 +131,6 @@ void ScriptController::clearScriptObjects()
}
}
-void ScriptController::clearForClose()
-{
- double start = currentTime();
- m_windowProxyManager->clearForClose();
- Platform::current()->histogramCustomCounts("WebCore.ScriptController.clearForClose", (currentTime() - start) * 1000, 0, 10000, 50);
-}
-
void ScriptController::updateSecurityOrigin(SecurityOrigin* origin)
{
m_windowProxyManager->mainWorldProxy()->updateSecurityOrigin(origin);
@@ -406,10 +399,10 @@ void ScriptController::clearWindowProxy()
double start = currentTime();
// The V8 context must be available for |clearScriptObjects()|.
// The below call must be before |clearForNavigation()| which disposes the V8 context.
clearScriptObjects();
- m_windowProxyManager->clearForNavigation();
+ m_windowProxyManager->clearWindowProxy();
Platform::current()->histogramCustomCounts("WebCore.ScriptController.clearWindowProxy", (currentTime() - start) * 1000, 0, 10000, 50);
}
@@ -406,10 +399,10 @@ void ScriptController::clearWindowProxy()
double start = currentTime();
// The V8 context must be available for |clearScriptObjects()|.
- // The below call must be before |clearForNavigation()| which disposes the V8 context.
+ // The below call must be before |clearWindowProxy()| which disposes the V8 context.
clearScriptObjects();

Powered by Google App Engine
This is Rietveld 408576698